import StockData from '../StockData';
import CandlestickFinder, { ICandlestickConfig } from './CandlestickFinder';
import { IDojiConfig } from './Doji';
/**
 * Configuration interface for AbandonedBaby pattern.
 * Only requires scale parameter since this pattern uses direct price comparisons.
 */
export interface IAbandonedBabyConfig extends ICandlestickConfig, IDojiConfig {
}
/**
 * Default configuration for AbandonedBaby pattern.
 */
export declare const DEFAULT_ABANDONED_BABY_CONFIG: IAbandonedBabyConfig;
export default class AbandonedBaby extends CandlestickFinder {
    private readonly config;
    constructor(config?: IAbandonedBabyConfig);
    logic(data: StockData): boolean;
}
/**
 * Detects Abandoned Baby candlestick pattern in the provided stock data.
 *
 * An Abandoned Baby is a rare three-candle reversal pattern consisting of:
 * 1. A bearish candle
 * 2. A doji that gaps down from the first candle
 * 3. A bullish candle that gaps up from the doji
 * This pattern indicates a strong reversal from bearish to bullish sentiment.
 *
 * @param data - Stock data containing OHLC values for at least 3 periods
 * @param config - Configuration object for pattern detection
 * @param config.scale - Scale parameter for approximateEqual function precision (default: 0.001)
 * @returns True if Abandoned Baby pattern is detected, false otherwise
 *
 * @example
 * ```typescript
 * // Using default configuration
 * const hasAbandonedBabyPattern = abandonedbaby(stockData);
 *
 * // Using custom configuration
 * const hasAbandonedBabyPattern = abandonedbaby(stockData, {
 *   scale: 0.002
 * });
 *
 * // Backward compatibility with scale parameter
 * const hasAbandonedBabyPattern = abandonedbaby(stockData, { scale: 0.002 });
 * ```
 */
export declare function abandonedbaby(data: StockData, config?: IAbandonedBabyConfig): any;
