import { IBearishEngulfingConfig } from './BearishEngulfingPattern';
import { IBearishHaramiConfig } from './BearishHarami';
import { IBearishHaramiCrossConfig } from './BearishHaramiCross';
import { IEveningDojiStarConfig } from './EveningDojiStar';
import { IEveningStarConfig } from './EveningStar';
import { IBearishMarubozuConfig } from './BearishMarubozu';
import { IThreeBlackCrowsConfig } from './ThreeBlackCrows';
import { IBearishHammerStickConfig } from './BearishHammerStick';
import { IBearishInvertedHammerConfig } from './BearishInvertedHammerStick';
import { IHangingManConfig } from './HangingMan';
import { IHangingManUnconfirmedConfig } from './HangingManUnconfirmed';
import { IShootingStarConfig } from './ShootingStar';
import { IShootingStarUnconfirmedConfig } from './ShootingStarUnconfirmed';
import { ITweezerTopConfig } from './TweezerTop';
import StockData from '../StockData';
import CandlestickFinder, { ICandlestickConfig } from './CandlestickFinder';
/**
 * Configuration interface for Bearish patterns composite.
 * Only requires scale parameter since this is a composite pattern.
 */
export interface IBearishConfig extends ICandlestickConfig, IBearishEngulfingConfig, IBearishHaramiConfig, IBearishHaramiCrossConfig, IEveningStarConfig, IEveningDojiStarConfig, IBearishMarubozuConfig, IThreeBlackCrowsConfig, IBearishHammerStickConfig, IBearishInvertedHammerConfig, IHangingManConfig, IHangingManUnconfirmedConfig, IShootingStarConfig, IShootingStarUnconfirmedConfig, ITweezerTopConfig {
}
/**
 * Default configuration for Bearish patterns composite.
 */
export declare const DEFAULT_BEARISH_CONFIG: IBearishConfig;
export default class BearishPatterns extends CandlestickFinder {
    bearishPatterns: CandlestickFinder[];
    constructor(config?: IBearishConfig);
    hasPattern(data: StockData): any;
}
/**
 * Detects any bearish candlestick pattern in the provided stock data.
 *
 * This function checks for multiple bearish candlestick patterns including:
 * - Bearish Engulfing Pattern
 * - Bearish Harami and Bearish Harami Cross
 * - Evening Star and Evening Doji Star
 * - Bearish Marubozu
 * - Three Black Crows
 * - Bearish Hammer Stick and Bearish Inverted Hammer Stick
 * - Hanging Man and Shooting Star patterns
 * - Tweezer Top
 *
 * @param data - Stock data containing OHLC values
 * @param config - Configuration object for pattern detection
 * @param config.scale - Scale parameter for approximateEqual function precision (default: 0.001)
 * @returns True if any bearish pattern is detected, false otherwise
 *
 * @example
 * ```typescript
 * // Using default configuration
 * const hasBearishPattern = bearish(stockData);
 *
 * // Using custom configuration
 * const hasBearishPattern = bearish(stockData, {
 *   scale: 0.002
 * });
 *
 * // Backward compatibility with scale parameter
 * const hasBearishPattern = bearish(stockData, { scale: 0.002 });
 * ```
 */
export declare function bearish(data: StockData, config?: IBearishConfig): any;
