import StockData from '../StockData';
import CandlestickFinder, { ICandlestickConfig } from './CandlestickFinder';
/**
 * Configuration interface for BearishEngulfingPattern.
 * Only requires scale parameter since this pattern uses direct price comparisons.
 */
export interface IBearishEngulfingConfig extends ICandlestickConfig {
}
/**
 * Default configuration for BearishEngulfingPattern.
 */
export declare const DEFAULT_BEARISH_ENGULFING_CONFIG: IBearishEngulfingConfig;
export default class BearishEngulfingPattern extends CandlestickFinder {
    constructor(config?: IBearishEngulfingConfig);
    logic(data: StockData): boolean;
}
/**
 * Detects Bearish Engulfing candlestick pattern in the provided stock data.
 *
 * A Bearish Engulfing pattern consists of two candlesticks where a large bearish candle
 * completely engulfs the previous smaller bullish candle. This pattern indicates a potential
 * reversal from bullish to bearish sentiment.
 *
 * @param data - Stock data containing OHLC values for at least 2 periods
 * @param config - Configuration object for pattern detection
 * @param config.scale - Scale parameter for approximateEqual function precision (default: 0.001)
 * @returns True if Bearish Engulfing pattern is detected, false otherwise
 *
 * @example
 * ```typescript
 * // Using default configuration
 * const hasBearishEngulfingPattern = bearishengulfingpattern(stockData);
 *
 * // Using custom configuration
 * const hasBearishEngulfingPattern = bearishengulfingpattern(stockData, {
 *   scale: 0.002
 * });
 *
 * // Backward compatibility with scale parameter
 * const hasBearishEngulfingPattern = bearishengulfingpattern(stockData, { scale: 0.002 });
 * ```
 */
export declare function bearishengulfingpattern(data: StockData, config?: IBearishEngulfingConfig): any;
