import { IMorningStarConfig } from './MorningStar';
import { IBullishEngulfingConfig } from './BullishEngulfingPattern';
import { IBullishHaramiConfig } from './BullishHarami';
import { IBullishHaramiCrossConfig } from './BullishHaramiCross';
import { IMorningDojiStarConfig } from './MorningDojiStar';
import { IBullishMarubozuConfig } from './BullishMarubozu';
import { IPiercingLineConfig } from './PiercingLine';
import { IThreeWhiteSoldiersConfig } from './ThreeWhiteSoldiers';
import { IBullishHammerConfig } from './BullishHammerStick';
import { IBullishInvertedHammerStickConfig } from './BullishInvertedHammerStick';
import { IHammerPatternConfig } from './HammerPattern';
import { IHammerPatternUnconfirmedConfig } from './HammerPatternUnconfirmed';
import StockData from '../StockData';
import CandlestickFinder, { ICandlestickConfig } from './CandlestickFinder';
import { ITweezerBottomConfig } from './TweezerBottom';
/**
 * Configuration interface for Bullish patterns composite.
 * Only requires scale parameter since this is a composite pattern.
 */
export interface IBullishConfig extends ICandlestickConfig, IBullishEngulfingConfig, IBullishHaramiConfig, IBullishHaramiCrossConfig, IMorningStarConfig, IMorningDojiStarConfig, IBullishMarubozuConfig, IPiercingLineConfig, IThreeWhiteSoldiersConfig, IBullishHammerConfig, IBullishInvertedHammerStickConfig, IHammerPatternConfig, IHammerPatternUnconfirmedConfig, ITweezerBottomConfig {
}
/**
 * Default configuration for Bullish patterns composite.
 */
export declare const DEFAULT_BULLISH_CONFIG: IBullishConfig;
export default class BullishPatterns extends CandlestickFinder {
    bullishPatterns: CandlestickFinder[];
    constructor(config?: IBullishConfig);
    hasPattern(data: StockData): any;
}
/**
 * Detects any bullish candlestick pattern in the provided stock data.
 *
 * This function checks for multiple bullish candlestick patterns including:
 * - Bullish Engulfing Pattern
 * - Bullish Harami and Bullish Harami Cross
 * - Morning Star and Morning Doji Star
 * - Bullish Marubozu
 * - Three White Soldiers
 * - Bullish Hammer Stick and Bullish Inverted Hammer Stick
 * - Hammer Pattern and Hammer Pattern Unconfirmed
 * - Downside Tasuki Gap, Piercing Line, and Tweezer Bottom
 *
 * @param data - Stock data containing OHLC values
 * @param config - Configuration object for pattern detection
 * @param config.scale - Scale parameter for approximateEqual function precision (default: 0.001)
 * @returns True if any bullish pattern is detected, false otherwise
 *
 * @example
 * ```typescript
 * // Using default configuration
 * const hasBullishPattern = bullish(stockData);
 *
 * // Using custom configuration
 * const hasBullishPattern = bullish(stockData, {
 *   scale: 0.002
 * });
 *
 * // Backward compatibility with scale parameter
 * const hasBullishPattern = bullish(stockData, { scale: 0.002 });
 * ```
 */
export declare function bullish(data: StockData, config?: IBullishConfig): any;
