import StockData from '../StockData';
import CandlestickFinder, { ICandlestickConfig } from './CandlestickFinder';
/**
 * Configuration interface for HangingMan pattern.
 * Includes thresholds for movement and confirmation analysis.
 */
export interface IHangingManConfig extends ICandlestickConfig {
    /** Minimum threshold for absolute measurements (default: 0.01) */
    minimumThreshold?: number;
    /** Absolute minimum for very small values (default: 0.001) */
    absoluteMinimum?: number;
    /** Movement threshold multiplier for confirmation (default: 1.0) */
    movementThresholdBase?: number;
    /** Movement threshold scale factor (default: 0.3) */
    movementThresholdScale?: number;
}
/**
 * Default configuration for HangingMan pattern.
 */
export declare const DEFAULT_HANGING_MAN_CONFIG: IHangingManConfig;
export default class HangingMan extends CandlestickFinder {
    private minimumThreshold;
    private absoluteMinimum;
    private movementThresholdBase;
    private movementThresholdScale;
    constructor(config?: IHangingManConfig);
    logic(data: StockData): boolean;
    upwardTrend(data: StockData): boolean;
    includesHammer(data: StockData): boolean;
    private isHammerLike;
    hasConfirmation(data: StockData): boolean;
}
export declare function hangingman(data: StockData, config?: IHangingManConfig): any;
